#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-notifications
version:              0.2.1.0
visibility:           public
id:                   hasql-notifications-0.2.1.0-8wcnvVYcyos1fN6oC5LKTH
key:                  hasql-notifications-0.2.1.0-8wcnvVYcyos1fN6oC5LKTH
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  a92bc727e145e98faa2f1c934f8b2343
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.1.0-8wcnvVYcyos1fN6oC5LKTH
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hasql-1.6.1.1-61bVMpYOqZDKhSgjX0Mb3G
    hasql-pool-0.8.0.3-Azo9uul5bOrBY3PiYVoyL
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

